"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.sql = exports.hasura = void 0;
const axios_1 = __importDefault(require("axios"));
const debug_1 = __importDefault(require("debug"));
const debug = debug_1.default('deepcase:migrations');
const HASURA_PATH = process.env.HASURA_PATH;
const HASURA_SSL = !!+process.env.HASURA_SSL;
const HASURA_SECRET = process.env.HASURA_SECRET;
if (!HASURA_PATH)
    throw new Error('!HASURA_PATH');
exports.hasura = {
    validateStatus: () => true,
    getError: (result) => {
        const { status } = result;
        const error = status >= 200 && status < 300 ? null : result.statusText;
        return error;
    },
    sql: (sql) => exports.hasura.query({
        type: 'run_sql',
        args: {
            sql,
        },
    }),
    query: (data) => __awaiter(void 0, void 0, void 0, function* () {
        debug('hasura:query', data === null || data === void 0 ? void 0 : data.type);
        const result = yield axios_1.default({
            method: 'post',
            url: `http${HASURA_SSL ? 's' : ''}://${HASURA_PATH}/v1/query`,
            headers: Object.assign({}, (HASURA_SECRET ? { 'x-hasura-admin-secret': HASURA_SECRET } : {})),
            data,
            validateStatus: exports.hasura.validateStatus,
        });
        result.error = exports.hasura.getError(result);
        if (result.error)
            debug('error', result === null || result === void 0 ? void 0 : result.error, result === null || result === void 0 ? void 0 : result.data);
        return result;
    }),
};
exports.sql = (strings, ...expr) => strings
    .map((str, index) => str + (expr.length > index ? String(expr[index]) : ''))
    .join('');
exports.default = exports.hasura;
//# sourceMappingURL=hasura.js.map